<?php

namespace Drupal\onehub;

use Drupal\onehub\OneHubApi;
use Drupal\Component\Utility\NestedArray;

class OneHubUpdater extends OneHubApi {

  /**
   * Utility function for updating OneHub Tables in the batch.
   *
   * @param bool $isBatch
   *   Are we setting a UI based batch or not.
   *
   * @return array
   */
  public function updateOneHub($isBatch = TRUE) {
    $workspaces = $this->listWorkspaces();

    foreach ($workspaces as $wid => $workspace) {
      $path = '/workspaces/' . $wid . '/folders';
      $f_call = $this->callApi($path);

      // Grab the id.
      $id = NestedArray::getValue($f_call, ['items', 0, 'folder', 'id']);

      // Call the API again to get the folders.
      $path = $path . '/' . $id;
      $fs_call = $this->callApi($path);

      $this->loadItems($fs_call, $isBatch);
    }
  }

  /**
   * Utility function to grab items in a OneHub Call.
   *
   * @param array $call
   *   The called array of items.
   * @param bool $isBatch
   *   Are we setting a UI based batch or not.
   *
   * @return array
   *   The list of items in an array keyed id:filename.
   */
  private function loadItems(array $call, $isBatch) {
    foreach ($call['items'] as $i) {
      foreach ($i as $item) {
        // If this item has children, then grab those.
        if (isset($item['children_count']) && $item['children_count'] > 0) {
          if ($isBatch) {
            $items[] = $item;
          }
          elseif (!$isBatch) {
            $queues[] = $item;
          }
          // Setup the right batch operations.
          $path = '/workspaces/' . $item['workspace_id'] . '/folders/' . $item['id'];
          $folders = $this->callApi($path);
          $this->loadItems($folders, $isBatch);
        }
        else {
          // Setup the right batch operations.
          if ($isBatch) {
            $items[] = $item;
          }
          elseif (!$isBatch) {
            $queues[] = $item;
          }
        }
      }
    }

    // For the regular batch.
    foreach ($items as $item) {
      $operations[] = ['Drupal\onehub\Batch\OneHubBatch::batchProcess', [$item]];
    }

    // This is for the queue based batch,
    if (isset($queues) && !$isBatch) {
      return $queues;
    }

    // This is for the ui based batch.
    if (isset($operations) && $isBatch) {
      // Set the batch to win the stuff.
      $batch = array(
        'title' => t('Importing OneHub File Info...'),
        'operations' => $operations,
        'init_message' => t('Importing Files to process.'),
        'finished' => 'Drupal\onehub\Batch\OneHubBatch::batchFinished',
        'file' => drupal_get_path('module', 'onehub') . '/src/Batch/OneHubBatch.php'
      );

      // Engage.
      batch_set($batch);
    }
    else {
      drupal_set_message(t('No Messages to Process!'), 'warning', TRUE);
    }

    // Fail safe return.
    return [];
  }
}